# Welcome to CSZP Easy Soccer Execution Program!

We are pleased to announce the launch of the CSZP Easy Soccer Execution Program (cszp). Thank you for using it.
I've checked and I believe this is your first time using it, so I'll give you a brief explanation of the operation.

If this is not your first time to use it, press the q key to go to the menu screen.

Also, if you want to read this text again, you can use the help command to confirm it.

## About the operation.

cszp incorporates interactive operations. So it's like a normal device.
 * Enter a command
 * Execution
 * The results will come back to you.
It will be executed in the form of (slightly different in detail)
Also, to make typing easier & easier to read, some of them have arrow keys, Tab key and mouse You can also use click.

## About the command.
For now, command input is done in the menu screen/setting screen, except for plugins. The format is as follows.
````
cszp Easy soccer execution program

start      Play a match
test       Play a test match
setting    Setting
reset      Reset
loop       Play multiple matchs
lang       Change language/言語を変更
server     Check the previous loop log on the server
plugin     Adding and checking plug-ins
about      Display cszp information
exit       Exit            
>>>
````
Left is a command and right is a brief description.
The command will be entered in the `>>>` box at the bottom.

## About help.

Execute the help command on the menu screen (the first screen you start up) and select the sentence you want to read. Use the up and down keys to select it and press Enter to confirm.

## About the License.
It is licensed under the GNU General Public License v3. See the following page for details.

[English version](https://github.com/kumitatepazuru/cszp/blob/master/LICENSE)

[Japanese version](https://github.com/kumitatepazuru/cszp/blob/master/LICENSE_jp)

## About Translations
For translation, Deepl 翻訳, みらい翻訳, Google 翻訳 .
I'm using machine translation, so there may be some things that don't seem right. If you see something that could be improved, please let me know in a cszp issue or pull request and I'll be happy to help. Please. Best regards.

## Acknowledgements

My head for coming up with this program, my jyo for helping me create this program Thank you so much to the _sen team.
I would like to take this opportunity to thank you.